@@ -1,11 +1,11 @@
 """sscu-budapest utilities for scientific data engineering"""
 # flake8: noqa
-from ._version import __version__
 from .metadata.datascript import (
     BaseEntity,
     CompositeTypeBase,
     IndexBase,
     Nullable,
+    SourceUrl,
     TableFeaturesBase,
 )
 from .metadata.datascript.scrutable import ScruTable
@@ -14,4 +14,4 @@ from .project_runtime import dump_dfs_to_tables
 from .reporting import ReportFile
 from .typer_commands import app
 
-__version__ = "0.2.3"
+__version__ = "0.2.5"
