@@ -1,7 +1,7 @@
 from pathlib import Path
 from typing import List, Type
 
-from yaml import safe_dump
+from yaml import safe_dump, safe_load
 
 from ...utils import load_named_dict_to_list
 from .atoms import ATOM_ID_KEY, NS_ATOM_TYPE
@@ -14,3 +14,10 @@ def dump_atom_list_to_dict(path: Path, atom_list: List[NS_ATOM_TYPE]):
 
 def load_atom_dict_to_list(path: Path, atom_cls: Type[NS_ATOM_TYPE]):
     return load_named_dict_to_list(path, atom_cls, key_name=ATOM_ID_KEY)
+
+
+def yaml_get(path: Path, default):
+    try:
+        return safe_load(path.read_text())
+    except FileNotFoundError:
+        return default
