@@ -19,6 +19,7 @@ from .naming import (
     MAIN_MODULE_NAME,
     SANDBOX_DIR,
     SANDBOX_NAME,
+    TEMPLATE_REPO,
 )
 from .pipeline_registry import get_global_pipereg
 from .registry import Registry
@@ -45,10 +46,16 @@ def publish_meta():
 
 
 @app.command()
-def update_registr():
+def update_registry():
     get_runtime(True).registry.update()
 
 
+@app.command()
+def init(name: str):
+    check_call(["git", "clone", TEMPLATE_REPO, name])
+    check_call(["git", "remote", "rename", "origin", "template"], cwd=name)
+
+
 @app.command()
 def publish_data(validate: bool = False):
     # TODO: current meta should be built and published
@@ -110,12 +117,12 @@ def cleanup():
 
 
 @app.command()
-def run_cronjobs(cronexpr: str = None):
+def run_cronjobs(cronexpr: str = None, commit: bool = True):
     runtime = get_runtime()
     for step in runtime.pipereg.steps:
         if step.cron == (cronexpr or os.environ.get(CRON_ENV_VAR)):
             runtime.config.bump_cron(step.name)
-    run(commit=True)
+    run(commit=commit)
 
 
 @app.command()
@@ -138,7 +145,6 @@ def run(
         dvc_repo.lock.lock()
         stage.remove_outs(force=True)
         dvc_repo.lock.unlock()
-
     targets = runtime.pipereg.step_names_of_env(env.name) if env else None
     rconf = RunConfig(profile=profile)
     with rconf:
